
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '37.0.0rc4',
    'branch_nick': 'master',
    'revision_id': '9df77d169e527191a39190f0c041a668dc411509',
    'revno': 13615
}
